# Galaxy Wrapper for WaveletMovies

To test the wrapper use `planemo`:

```bash
# install
conda install planemo

# run the test(s)
planemo test

# run a local galaxy instance with the tool installed
planemo serve

```
